@@ -19,13 +19,14 @@ limitations under the License.
 """
 
 # import required libraries
-import re, logging, os
+import re, logging, os, platform
 import numpy as np
 
 # import utils packages
 from .utils import logger_handler
 from .ffhelper import (
     check_sp_output,
+    get_supported_demuxers,
     is_valid_url,
     is_valid_image_seq,
     get_valid_ffmpeg_path,
@@ -41,7 +42,14 @@ logger.setLevel(logging.DEBUG)
 class Sourcer:
     """ """
 
-    def __init__(self, source, custom_ffmpeg="", verbose=False, **sourcer_params):
+    def __init__(
+        self,
+        source,
+        source_demuxer=None,
+        custom_ffmpeg="",
+        verbose=False,
+        **sourcer_params
+    ):
         """
         This constructor method initializes the object state and attributes of the Sourcer.
 
@@ -101,9 +109,12 @@ class Sourcer:
 
         # define externally accessible parameters
         self.__source = source  # handles source stream
-        self.__source_extension = os.path.splitext(source)[
-            -1
-        ]  # handles source stream extension
+        # handles source demuxer
+        self.__source_demuxer = (
+            source_demuxer.strip().lower() if isinstance(source_demuxer, str) else None
+        )
+        # handles source stream extension
+        self.__source_extension = os.path.splitext(source)[-1]
         self.__default_video_resolution = ""  # handle stream resolution
         self.__default_video_framerate = ""  # handle stream framerate
         self.__default_video_bitrate = ""  # handle stream's video bitrate
@@ -137,7 +148,13 @@ class Sourcer:
             and all(isinstance(x, int) for x in default_stream_indexes)
         ), "Invalid default_stream_indexes value!"
         # validate source and extract metadata
-        self.__ffsp_output = self.__validate_source(self.__source)
+        self.__ffsp_output = self.__validate_source(
+            self.__source,
+            source_demuxer=self.__source_demuxer,
+            forced_validate=(
+                self.__forcevalidatesource if self.__source_demuxer is None else True
+            ),
+        )
         # parse resolution and framerate
         video_rfparams = self.__extract_resolution_framerate(
             default_stream=default_stream_indexes[0]
@@ -209,50 +226,71 @@ class Sourcer:
         metadata = {
             "ffmpeg_binary_path": self.__ffmpeg,
             "source": self.__source,
-            "source_extension": self.__source_extension,
-            "source_video_resolution": self.__default_video_resolution,
-            "source_video_framerate": self.__default_video_framerate,
-            "source_video_pixfmt": self.__default_video_pixfmt,
-            "source_video_decoder": self.__default_video_decoder,
-            "source_duration_sec": self.__default_source_duration,
-            "approx_video_nframes": int(self.__approx_video_nframes)
-            if self.__approx_video_nframes
-            else None,
-            "source_video_bitrate": self.__default_video_bitrate,
-            "source_audio_bitrate": self.__default_audio_bitrate,
-            "source_audio_samplerate": self.__default_audio_samplerate,
-            "source_has_video": self.__contains_video,
-            "source_has_audio": self.__contains_audio,
-            "source_has_image_sequence": self.__contains_images,
         }
+        metadata.update(
+            {"source_extension": self.__source_extension}
+            if self.__source_demuxer is None
+            else {"source_demuxer": self.__source_demuxer}
+        )
+        metadata.update(
+            {
+                "source_video_resolution": self.__default_video_resolution,
+                "source_video_framerate": self.__default_video_framerate,
+                "source_video_pixfmt": self.__default_video_pixfmt,
+                "source_video_decoder": self.__default_video_decoder,
+                "source_duration_sec": self.__default_source_duration,
+                "approx_video_nframes": (
+                    int(self.__approx_video_nframes)
+                    if self.__approx_video_nframes
+                    else None
+                ),
+                "source_video_bitrate": self.__default_video_bitrate,
+                "source_audio_bitrate": self.__default_audio_bitrate,
+                "source_audio_samplerate": self.__default_audio_samplerate,
+                "source_has_video": self.__contains_video,
+                "source_has_audio": self.__contains_audio,
+                "source_has_image_sequence": self.__contains_images,
+            }
+        )
         return metadata
 
-    def __validate_source(self, source):
+    def __validate_source(self, source, source_demuxer=None, forced_validate=False):
         """
         Internal method for validating source and extract its FFmpeg metadata.
         """
-        if source is None or not source or not isinstance(source, str):
-            raise ValueError("Input source is empty!")
+        # assert if valid source
+        assert source and isinstance(source, str), "Input source is empty!"
+        # assert if valid source demuxer
+        assert source_demuxer is None or source_demuxer in get_supported_demuxers(
+            self.__ffmpeg
+        ), "Installed FFmpeg failed to recognise `{}` demuxer. Check ``source_demuxer`` parameter value again!".format(
+            source_demuxer
+        )
         # Differentiate input
-        if os.path.isfile(source):
-            self.__video_source = os.path.abspath(source)
+        if forced_validate:
+            source_demuxer is None and logger.critical(
+                "Forcefully passing validation test for given source!"
+            )
+            self.__source = source
+        elif os.path.isfile(source):
+            self.__source = os.path.abspath(source)
         elif is_valid_image_seq(
             self.__ffmpeg, source=source, verbose=self.__verbose_logs
         ):
-            self.__video_source = source
+            self.__source = source
             self.__contains_images = True
         elif is_valid_url(self.__ffmpeg, url=source, verbose=self.__verbose_logs):
-            self.__video_source = source
-        elif self.__forcevalidatesource:
-            logger.critical("Forcefully passing validation test for given source!")
-            self.__video_source = source
+            self.__source = source
         else:
             logger.error("`source` value is unusable or unsupported!")
             # discard the value otherwise
             raise ValueError("Input source is invalid. Aborting!")
         # extract metadata
         metadata = check_sp_output(
-            [self.__ffmpeg, "-hide_banner", "-i", source], force_retrieve_stderr=True
+            [self.__ffmpeg, "-hide_banner"]
+            + (["-f", source_demuxer] if source_demuxer else [])
+            + ["-i", source],
+            force_retrieve_stderr=True,
         )
         # filter and return
         return metadata.decode("utf-8").strip()
